@@ -214,7 +214,7 @@ from ae.gui_app import (
     FLOW_KEY_SEP, flow_action, flow_class_name, flow_path_id, id_of_flow, update_tap_kwargs, MainAppBase)
 
 
-__version__ = '0.3.44'
+__version__ = '0.3.45'
 
 
 register_package_translations()
@@ -1160,14 +1160,18 @@ class HelpAppBase(MainAppBase, ABC):
         :param tour_class:          optional tour (pages) class, default: tour of current help id or `OnboardingTour`.
         :return:                    True if UI-framework support tours/has tour_overlay_class set and tour got started.
         """
-        tour_layout_class = self.tour_overlay_class
-        if tour_layout_class:
-            if self.tour_layout:
-                self.tour_layout.stop_tour()
-            tour_layout_class(self, tour_class=tour_class)  # pylint: disable=not-callable # false positive
-        else:
-            self.vpo("HelpAppBase.start_app_tour called but tour overlay/layout class got not set")
+        if not self.help_activator:
+            self.po("HelpAppBase.start_app_tour(): tour start cancelled because help activator button is missing")
+            return False
 
+        tour_layout_class = self.tour_overlay_class
+        if not tour_layout_class:
+            self.po("HelpAppBase.start_app_tour(): tour start cancelled because tour overlay/layout class is not set")
+            return False
+
+        if self.tour_layout:
+            self.tour_layout.stop_tour()
+        tour_layout_class(self, tour_class=tour_class)  # pylint: disable=not-callable # false positive
         return bool(self.tour_layout)   # overlay instance sets main_app./framework_app.tour_layout on tour start
 
     def widget_by_page_id(self, page_id: str) -> Optional[Any]:
